pub struct CreateCardRequest {
pub board_id: String,
pub column_id: String,
pub title: String,
pub description: Option<String>,
pub priority: Option<String>,
pub points: Option<u8>,
pub due_date: Option<String>,
}Fields
board_id: Stringcolumn_id: Stringtitle: Stringdescription: Option<String>priority: Option<String>points: Option<u8>due_date: Option<String>Trait Implementations
Sourceimpl Debug for CreateCardRequest
impl Debug for CreateCardRequest
Sourceimpl<'de> Deserialize<'de> for CreateCardRequest
impl<'de> Deserialize<'de> for CreateCardRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateCardRequest
impl JsonSchema for CreateCardRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateCardRequest
impl RefUnwindSafe for CreateCardRequest
impl Send for CreateCardRequest
impl Sync for CreateCardRequest
impl Unpin for CreateCardRequest
impl UnwindSafe for CreateCardRequest