pub struct MoveCardRequest {
pub card_id: String,
pub column_id: String,
pub position: Option<i32>,
}Fields
card_id: Stringcolumn_id: Stringposition: Option<i32>Trait Implementations
Sourceimpl Debug for MoveCardRequest
impl Debug for MoveCardRequest
Sourceimpl<'de> Deserialize<'de> for MoveCardRequest
impl<'de> Deserialize<'de> for MoveCardRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MoveCardRequest
impl JsonSchema for MoveCardRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MoveCardRequest
impl RefUnwindSafe for MoveCardRequest
impl Send for MoveCardRequest
impl Sync for MoveCardRequest
impl Unpin for MoveCardRequest
impl UnwindSafe for MoveCardRequest